@@ -22,6 +22,19 @@ test_that("We can pass a species_list based on taxanomic group", {
   fish <- species_list(Genus = "Labroides") 
   df <- species(fish)
   expect_is(df, "data.frame")
+  expect_gt(dim(df)[1], 0)
+  
+  
+})
+
+test_that("We can pass a species_list based on taxanomic group", {
+  
+  needs_api()  
+  fish <- species_list(Genus = "Labroides") 
+  df <- species(fish)
+  expect_is(df, "data.frame")
+  expect_gt(dim(df)[1], 0)
+  
   
 })
 
@@ -31,6 +44,9 @@ test_that("We can filter on certain fields",{
   df <- species(c("Oreochromis niloticus", "Bolbometopon muricatum"), 
                 fields=c('SpecCode', 'Species'))
   expect_is(df, "data.frame")
+  expect_gt(dim(df)[1], 0)
+  
+  df <- load_species_meta()
   
 })
 
