@@ -7,7 +7,7 @@ test_that("synonyms can query by species", {
   
   df <- synonyms("Callyodon muricatus")
   expect_is(df, "data.frame")
-  expect_equal(df$SpecCode[[1]], 5537)
+  expect_equal(as.numeric(df$SpecCode[[1]]), 5537)
 })
 
 test_that("synonyms can resolve misspellings", {
@@ -15,10 +15,17 @@ test_that("synonyms can resolve misspellings", {
   needs_api()
   
   x <- synonyms("Labroides dimidatus") # Species name misspelled
-  expect_equal(species_list(SpecCode = x$SpecCode), "Labroides dimidiatus")
+  expect_equal(x %>% pull(Species), "Labroides dimidiatus")
 })
   
 
+test_that("synonyms can resolve in sealifebase", {
+  
+  needs_api()
+  
+  x <- synonyms(server="sealifebase") 
+  expect_is(x, "tbl")
+})
 
 test_that("We can validate names",{
 
@@ -26,6 +33,9 @@ test_that("We can validate names",{
   x <- validate_names("Clupea pallasii")
   expect_is(x, "character")
   expect_identical(x, "Clupea pallasii pallasii")
+
+  x <- validate_names(c(rep("Agonomalus jordani", 2), "wrong"))
+  expect_identical(x, c(rep("Agonomalus jordani", 2), NA))
 })
 
 
